@@ -28,8 +28,6 @@ sub connect {
     return $self->SUPER::connect;
 }
 
-sub last_insert_id { shift->dbh->{mysql_insertid} }
-
 1;
 
 =head1 NAME
@@ -100,11 +98,4 @@ This method overrides C<DBIx::Custom::connect()> method.
 You can specify all attributes of L<DBIx::Custom>
 and L<DBIx::Custom::MySQL>, such as C<database>, C<host>, C<port>.
 
-=head2 C<last_insert_id>
-
-    my $last_insert_id = $dbi->last_insert_id;
-
-Get last insert id.
-This is same as C<last_insert_id()> function in MySQL.
-
 =cut
